@@ -7,7 +7,8 @@ set -x
 if [ -f ./test.db ]; then
     rm ./test.db
 fi
-
+bash ./scripts/lint.sh
+# Check README.md is up to date
+diff --brief docs/index.md README.md
 export PYTHONPATH=./docs/src
 pytest --cov=fastapi --cov=tests --cov=docs/src --cov-report=term-missing ${@}
-bash ./scripts/lint.sh
