@@ -4,7 +4,7 @@ from async_sql_databases.tutorial001 import app
 
 openapi_schema = {
     "openapi": "3.0.2",
-    "info": {"title": "Fast API", "version": "0.1.0"},
+    "info": {"title": "FastAPI", "version": "0.1.0"},
     "paths": {
         "/notes/": {
             "get": {
@@ -14,7 +14,7 @@ openapi_schema = {
                         "content": {
                             "application/json": {
                                 "schema": {
-                                    "title": "Response_Read_Notes_Notes__Get",
+                                    "title": "Response Read Notes Notes  Get",
                                     "type": "array",
                                     "items": {"$ref": "#/components/schemas/Note"},
                                 }
