@@ -6,7 +6,7 @@ client = TestClient(app)
 
 openapi_schema = {
     "openapi": "3.0.2",
-    "info": {"title": "Fast API", "version": "0.1.0"},
+    "info": {"title": "FastAPI", "version": "0.1.0"},
     "paths": {
         "/items-header/{item_id}": {
             "get": {
@@ -27,11 +27,11 @@ openapi_schema = {
                     },
                 },
                 "summary": "Read Item Header",
-                "operationId": "read_item_header_items-header__item_id__get",
+                "operationId": "read_item_header_items_header__item_id__get",
                 "parameters": [
                     {
                         "required": True,
-                        "schema": {"title": "Item_Id", "type": "string"},
+                        "schema": {"title": "Item Id", "type": "string"},
                         "name": "item_id",
                         "in": "path",
                     }
