@@ -7,7 +7,7 @@ client = TestClient(app)
 
 openapi_schema = {
     "openapi": "3.0.2",
-    "info": {"title": "Fast API", "version": "0.1.0"},
+    "info": {"title": "FastAPI", "version": "0.1.0"},
     "paths": {
         "/model/{model_name}": {
             "get": {
@@ -33,7 +33,7 @@ openapi_schema = {
                     {
                         "required": True,
                         "schema": {
-                            "title": "Model_Name",
+                            "title": "Model Name",
                             "enum": ["alexnet", "resnet", "lenet"],
                             "type": "string",
                         },
@@ -106,8 +106,9 @@ def test_openapi():
             {
                 "detail": [
                     {
+                        "ctx": {"enum_values": ["alexnet", "resnet", "lenet"]},
                         "loc": ["path", "model_name"],
-                        "msg": "value is not a valid enumeration member",
+                        "msg": "value is not a valid enumeration member; permitted: 'alexnet', 'resnet', 'lenet'",
                         "type": "type_error.enum",
                     }
                 ]
