@@ -1,12 +1,11 @@
+from pathlib import Path
+
+import pytest
 from starlette.testclient import TestClient
 
-from sql_databases.sql_app.main import app
-
-client = TestClient(app)
-
 openapi_schema = {
     "openapi": "3.0.2",
-    "info": {"title": "Fast API", "version": "0.1.0"},
+    "info": {"title": "FastAPI", "version": "0.1.0"},
     "paths": {
         "/users/": {
             "get": {
@@ -16,7 +15,7 @@ openapi_schema = {
                         "content": {
                             "application/json": {
                                 "schema": {
-                                    "title": "Response_Read_Users_Users__Get",
+                                    "title": "Response Read Users Users  Get",
                                     "type": "array",
                                     "items": {"$ref": "#/components/schemas/User"},
                                 }
@@ -111,7 +110,7 @@ openapi_schema = {
                 "parameters": [
                     {
                         "required": True,
-                        "schema": {"title": "User_Id", "type": "integer"},
+                        "schema": {"title": "User Id", "type": "integer"},
                         "name": "user_id",
                         "in": "path",
                     }
@@ -145,7 +144,7 @@ openapi_schema = {
                 "parameters": [
                     {
                         "required": True,
-                        "schema": {"title": "User_Id", "type": "integer"},
+                        "schema": {"title": "User Id", "type": "integer"},
                         "name": "user_id",
                         "in": "path",
                     }
@@ -168,7 +167,7 @@ openapi_schema = {
                         "content": {
                             "application/json": {
                                 "schema": {
-                                    "title": "Response_Read_Items_Items__Get",
+                                    "title": "Response Read Items Items  Get",
                                     "type": "array",
                                     "items": {"$ref": "#/components/schemas/Item"},
                                 }
@@ -224,7 +223,7 @@ openapi_schema = {
                     "title": {"title": "Title", "type": "string"},
                     "description": {"title": "Description", "type": "string"},
                     "id": {"title": "Id", "type": "integer"},
-                    "owner_id": {"title": "Owner_Id", "type": "integer"},
+                    "owner_id": {"title": "Owner Id", "type": "integer"},
                 },
             },
             "User": {
@@ -234,7 +233,7 @@ openapi_schema = {
                 "properties": {
                     "email": {"title": "Email", "type": "string"},
                     "id": {"title": "Id", "type": "integer"},
-                    "is_active": {"title": "Is_Active", "type": "boolean"},
+                    "is_active": {"title": "Is Active", "type": "boolean"},
                     "items": {
                         "title": "Items",
                         "type": "array",
@@ -282,13 +281,24 @@ openapi_schema = {
 }
 
 
-def test_openapi_schema():
+@pytest.fixture(scope="module")
+def client():
+    # Import while creating the client to create the DB after starting the test session
+    from sql_databases.sql_app.main import app
+
+    test_db = Path("./test.db")
+    with TestClient(app) as c:
+        yield c
+    test_db.unlink()
+
+
+def test_openapi_schema(client):
     response = client.get("/openapi.json")
     assert response.status_code == 200
     assert response.json() == openapi_schema
 
 
-def test_create_user():
+def test_create_user(client):
     test_user = {"email": "johndoe@example.com", "password": "secret"}
     response = client.post("/users/", json=test_user)
     assert response.status_code == 200
@@ -299,7 +309,7 @@ def test_create_user():
     assert response.status_code == 400
 
 
-def test_get_user():
+def test_get_user(client):
     response = client.get("/users/1")
     assert response.status_code == 200
     data = response.json()
@@ -307,12 +317,12 @@ def test_get_user():
     assert "id" in data
 
 
-def test_inexistent_user():
+def test_inexistent_user(client):
     response = client.get("/users/999")
     assert response.status_code == 404
 
 
-def test_get_users():
+def test_get_users(client):
     response = client.get("/users/")
     assert response.status_code == 200
     data = response.json()
@@ -320,7 +330,7 @@ def test_get_users():
     assert "id" in data[0]
 
 
-def test_create_item():
+def test_create_item(client):
     item = {"title": "Foo", "description": "Something that fights"}
     response = client.post("/users/1/items/", json=item)
     assert response.status_code == 200
@@ -343,7 +353,7 @@ def test_create_item():
     assert item_to_check["description"] == item["description"]
 
 
-def test_read_items():
+def test_read_items(client):
     response = client.get("/items/")
     assert response.status_code == 200
     data = response.json()
